@@ -77,7 +77,7 @@ void SurfaceTest::testIncorrect()
 
     PlotBuilder rp = PlotsFactory::self()->requestPlot(Expression(input), Dim3D);
     if(rp.canDraw()) {
-        FunctionGraph* f = rp.create(Qt::red, "lala");
+        FunctionGraph* f = rp.create(Qt::red, QStringLiteral("lala"));
         Surface* surface = dynamic_cast<Surface*>(f);
         QVERIFY(surface);
         
@@ -126,7 +126,7 @@ void SurfaceTest::testIncorrect()
 // 
 //     //Interval as expression
 //     QVERIFY(f3->setInterval(param, interval_expression.first, interval_expression.second));
-//     QCOMPARE(f3->interval(param, true).second.toString(), QString("16"));
+//     QCOMPARE(f3->interval(param, true).second.toString(), QStringLiteral("16"));
 //     
 //     delete m_vars->take("a");
 //     delete m_vars->take("b");
