@@ -21,10 +21,6 @@
 #ifndef PLOTSVIEW3DES_H
 #define PLOTSVIEW3DES_H
 
-#ifdef _WIN32
-#include <GL/glew.h>
-#endif
-
 #include <QOpenGLWidget>
 #include <QMouseEvent>
 
@@ -50,7 +46,7 @@ class PlotItem;
  * use Plotter3D and OpenGL as a backend.
  */
 
-class ANALITZAWIDGETS_EXPORT PlotsView3DES : public  QOpenGLWidget, public Plotter3DES
+class ANALITZAWIDGETS_EXPORT PlotsView3DES : public QOpenGLWidget, public Plotter3DES
 {
     Q_OBJECT
 
@@ -60,9 +56,6 @@ public:
 
     void setSelectionModel(QItemSelectionModel* selection);
 
-public Q_SLOTS:
-    void resetView();
-    
 private Q_SLOTS:
     void updateFuncs(const QModelIndex &indexf,const QModelIndex &indext);
     void addFuncs(const QModelIndex &index,int,int);
@@ -82,6 +75,7 @@ private:
     virtual void paintGL() override;
     virtual void initializeGL() override;
     virtual void resizeGL(int width, int height) override;
+    QImage grabImage() override;
     
     QItemSelectionModel* m_selection;
     
